# Extras API

This page documents the extra adapters provided by pydapter.

## Excel Adapter

::: pydapter.extras.excel_ options: show_root_heading: true show_source: true

## Pandas Adapter

::: pydapter.extras.pandas_ options: show_root_heading: true show_source: true

## SQL Adapter

::: pydapter.extras.sql_ options: show_root_heading: true show_source: true

## PostgreSQL Adapter

::: pydapter.extras.postgres_ options: show_root_heading: true show_source: true

## MongoDB Adapter

::: pydapter.extras.mongo_ options: show_root_heading: true show_source: true

## Neo4j Adapter

::: pydapter.extras.neo4j_ options: show_root_heading: true show_source: true

## Qdrant Adapter

::: pydapter.extras.qdrant_ options: show_root_heading: true show_source: true

## Async SQL Adapter

::: pydapter.extras.async_sql_ options: show_root_heading: true show_source:
true

## Async PostgreSQL Adapter

::: pydapter.extras.async_postgres_ options: show_root_heading: true
show_source: true

## Async MongoDB Adapter

::: pydapter.extras.async_mongo_ options: show_root_heading: true show_source:
true

## Async Qdrant Adapter

::: pydapter.extras.async_qdrant_ options: show_root_heading: true show_source:
true
